@@ -401,16 +401,18 @@ class Form(TagMixin, metaclass=FormMeta):
         # should never be called externally. Triggered by bind.
         obj_mapping = self._bound_object_mapping or {}
         for field_name, field in self.fields.items():
-            attr = field_name
             current_obj = self._bound_object
+            attr = field_name
             if field_name in obj_mapping:
-                for name in obj_mapping[field_name][0:-1]:
+                attr = obj_mapping[field_name][-1]
+                fields = obj_mapping[field_name][0:-1]
+                for name in fields:
                     try:
                         current_obj = getattr(current_obj, name)
                     except:
                         raise AttributeError(
                             'Mapping for object does not match object structure.')
-            if hasattr(current_obj, attr):
+            if hasattr(current_obj, attr) and attr not in self._ignored_bound_fields:
                 self.fields[field_name].value = getattr(current_obj, attr)
 
     def __hydrate_form_to_obj(self):
